@@ -64,10 +64,7 @@
 #include "incl_unix.h"
 #include "incl_ugid.h"
 #include "cfile.h"
-#ifdef	SHAREDLIBS
 #include "xfershm.h"
-#include "displayopt.h"
-#endif
 
 #define	INCPAGES	10	/* Incremental size */
 
@@ -102,24 +99,10 @@ extern	int	pfile,
 		lfid,
 		outb_ptr;
 
-int	Ctrl_chan;
-
 LONG	Num_sent,
 	Pages_done,
 	My_msgid;
 
-#if  	defined(RUN_AS_ROOT) || defined(SHAREDLIBS)
-uid_t	Daemuid;
-#endif
-#ifdef	SHAREDLIBS
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-uid_t	Realuid, Effuid;
-struct	xfershm		*Xfer_shmp;
-DEF_DISPOPTS;
-#endif
-
 /* These bits all relate to shared memory ops.  */
 
 int	Ptrslot;		/*  This is index of Pptr in Job_seg.plist  */
@@ -131,8 +114,6 @@ union	{			/*  Dummy ones to save testing  */
 }  dummy;
 struct	spq	*Cjob = &dummy.jq;	/*  Current job */
 struct	spptr	*Pptr = &dummy.pq;	/*  Current ptr descr */
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
 char	*formp, *prtp;
 extern	PIDTYPE	childproc;
 extern	struct	initpkt	in_params;
@@ -185,7 +166,7 @@ char	*Ep_spfl = Ev_spfl+11, *Ep_sppg = Ev_sppg+10;
 char	*Ep_spjob = Ev_spjob + 9, *Ep_sphost = Ev_sphost + 10;
 char	*Ep_range = Ev_sprange+11, *Ep_spoe = Ev_spoe+8, *Ep_spcps = Ev_spcps + 9;
 
-FILE	*Cfile, *ffile;
+FILE	*ffile;
 struct	pages	pfe;
 
 char	*ptdir,
@@ -1672,7 +1653,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 	char	*fname;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 1);
+	versionprint(argv, "$Revision: 1.2 $", 1);
 
 	umask(C_MASK);
 	init_mcfile();
@@ -1722,10 +1703,8 @@ MAINFN_TYPE	main(int argc, char **argv)
 	ptdir = envprocess(PTDIR);
 	shellname = envprocess(SHELL);
 
-#ifdef	SHAREDLIBS
 	Realuid = getuid();
 	Effuid = geteuid();
-#endif
 #ifdef	RUN_AS_ROOT
 	if  ((Daemuid = lookup_uname(SPUNAME)) == UNKNOWN_UID)
 		Daemuid = ROOTID;
