@@ -82,8 +82,6 @@ int	LINES;			/* Not defined anywhere without extern */
 
 #define	P_DONT_CARE	100
 
-#define	BOXWID	1
-
 void	cjfind(void);
 void	jdisplay(void);
 void	openjfile(void);
@@ -97,18 +95,10 @@ int	j_process(void);
 char *	get_jobtitle(int);
 char *	get_ptrtitle(void);
 
-FILE	*Cfile;
 char	Win_setup, jset;
 static	jmp_buf	Mj;
 
 #define	IPC_MODE	0600
-int	Ctrl_chan = -1;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
-struct	xfershm		*Xfer_shmp;
 
 unsigned	Pollinit,	/* Initial polling */
 		Pollfreq;	/* Current polling frequency */
@@ -116,23 +106,16 @@ unsigned	Pollinit,	/* Initial polling */
 time_t	hadalarm,
 	lastalarm;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
 int	hadrfresh,
 	wh_jtitline,
 	wh_ptitline;
 
 char	scrkeep,
-	helpclr,
-	helpbox,
-	errbox,
 	nopage,
 	pfirst = P_DONT_CARE,
 	confabort = 1;
 
-DEF_DISPOPTS;
+extern	char	helpclr, helpbox, errbox;	/* def moved to library wgets */
 
 char	*Realuname;
 
@@ -154,9 +137,7 @@ WINDOW	*hjscr,
 	*hpscr,
 	*tpscr,
 	*jscr,
-	*pscr,
-	*hlpscr,
-	*escr;
+	*pscr;
 
 char	*ptdir,
 	*spdir,
@@ -168,6 +149,9 @@ struct	termios	orig_term;
 struct	termio	orig_term;
 #endif
 
+extern	void	dohelp(WINDOW *, struct sctrl *, const char *);
+extern	void	doerror(WINDOW *, const int);
+
 /* If we get a message error die appropriately */
 
 void	msg_error(const int ret)
@@ -245,10 +229,10 @@ void	my_wpmsg(const int act)
 
 /* This notes signals from (presumably) the scheduler.  */
 
-RETSIGTYPE	markit(int sig)
+RETSIGTYPE	sh_markit(int sig)
 {
 #ifdef	UNSAFE_SIGNALS		/* QUICK!!!! */
-	signal(sig, markit);
+	signal(sig, sh_markit);
 #endif
 	if  (sig != QRFRESH)  {
 #ifndef	HAVE_ATEXIT
@@ -318,155 +302,8 @@ RETSIGTYPE	sigerr(int n)
 	exit(E_SIGNAL);
 }
 
-/* Generate help message.  */
 
-void	dohelp(WINDOW * owin, struct sctrl * scp, const char * prefix)
-{
-	char	**hv, **examples = (char **) 0;
-	int	hrows, hcols, erows, ecols, cols, rows;
-	int	begy, cy, cx, startrow, startcol, k, edrows, edcols;
-	int	rpadding, icpadding;
-	int	i, j;
-
-	if  (*(hv = helpvec(scp->helpcode, 'H')) == (char *) 0)  {
-		free((char *) hv);
-		disp_arg[0] = scp->helpcode;
-		hv = helpvec($E{Missing help code}, 'E');
-	}
-
-	if  (scp->helpfn)
-		examples = (*scp->helpfn)(prefix, 1);
-
-	count_hv(hv, &hrows, &hcols);
-	count_hv(examples, &erows, &ecols);
-	cols = hcols;
-	edcols = 1;
-	edrows = erows;
-	rpadding = 0;
-	icpadding = 1;
-
-	if  (ecols > cols)
-		cols = ecols;
-	else  if  ((edcols = hcols / (ecols + 1)) <= 0)
-			edcols = 1;
-	else  {
-		if  (edcols > erows)
-			edcols = erows;
-		if  ((i = edcols - 1) > 0)  {
-			edrows = (erows - 1) / edcols + 1;
-			rpadding = cols - edcols * ecols;
-			icpadding = rpadding / i;
-			if  (icpadding > 5)
-				icpadding = 5;
-			rpadding = (cols - ecols * edcols - icpadding * i) / 2;
-		}
-	}
-
-	rows = hrows + edrows;
-	if  (helpbox)  {
-		rows += 2 * BOXWID;
-		cols += 2 * BOXWID;
-	}
-
-	if  (rows >= LINES)  {
-		edrows -= rows - LINES + 1;
-		rows = LINES-1;
-	}
-
-	/* Find absolute cursor position and try to create window avoiding it.  */
-
-	getbegyx(owin, begy, cx);
-	getyx(owin, cy, cx);
-	cy += begy;
-	if  ((startrow = cy - rows/2) < 0)
-		startrow = 0;
-	else  if  (startrow + rows > LINES)
-		startrow = LINES - rows;
-	if  ((startcol = cx - cols/2) < 0)
-		startcol = 0;
-	else  if  (startcol + cols > COLS)
-		startcol = COLS - cols;
-
-	if  (cx + cols + 2 < COLS)
-		startcol = COLS - cols - 1;
-	else  if  (cx - cols - 1 >= 0)
-		startcol = cx - cols - 1;
-	else  if  (cy + rows + 2 < LINES)
-		startrow = cy + 2;
-	else  if  (cy - rows - 1 >= 0)
-		startrow = cy - rows - 1;
-
-	if  ((hlpscr = newwin(rows <= 0? 1: rows, cols, startrow, startcol)) == (WINDOW *) 0)
-		nomem();
-
-	if  (helpbox)  {
-#ifdef	HAVE_TERMINFO
-		box(hlpscr, 0, 0);
-#else
-		box(hlpscr, '|', '-');
-#endif
-		for  (i = 0;  i < hrows;  i++)
-			mvwaddstr(hlpscr, i+BOXWID, BOXWID, hv[i]);
-
-		for  (i = 0;  i < edrows;  i++)  {
-			int	ccol = rpadding + BOXWID;
-			wmove(hlpscr, i + hrows + BOXWID, ccol);
-			for  (j = 0;  j < edcols - 1;  j++)  {
-				if  ((k = i + j*edrows) < erows)
-					waddstr(hlpscr, examples[k]);
-				ccol += ecols + icpadding;
-				wmove(hlpscr, i + hrows + BOXWID, ccol);
-			}
-			if  ((k = i + (edcols - 1) * edrows) < erows)
-				waddstr(hlpscr, examples[k]);
-		}
-	}
-	else  {
-		wstandout(hlpscr);
-
-		for  (i = 0;  i < hrows;  i++)  {
-			mvwaddstr(hlpscr, i, 0, hv[i]);
-			for  (cx = strlen(hv[i]);  cx < cols;  cx++)
-				waddch(hlpscr, ' ');
-		}
-
-		for  (i = 0;  i < edrows;  i++)  {
-			wmove(hlpscr, i+hrows, 0);
-			for  (cx = 0;  cx < rpadding;  cx++)
-				waddch(hlpscr, ' ');
-			for  (j = 0;;  j++)  {
-				if  ((k = i + j*edrows) < erows)  {
-					waddstr(hlpscr, examples[k]);
-					k = strlen(examples[k]);
-				}
-				else
-					k = 0;
-				for  (;  k < ecols;  k++)
-					waddch(hlpscr, ' ');
-				if  (j >= edcols - 1)  {
-					for  (k = (edcols - 1) * (ecols + icpadding) + ecols;  k < cols;  k++)
-						waddch(hlpscr, ' ');
-					break;
-				}
-				for  (k = 0;  k < icpadding;  k++)
-					waddch(hlpscr, ' ');
-			}
-		}
-	}
-	freehelp(hv);
-	freehelp(examples);
-
-#ifdef HAVE_TERMINFO
-	wnoutrefresh(hlpscr);
-	wnoutrefresh(owin);
-	doupdate();
-#else
-	wrefresh(hlpscr);
-	wrefresh(owin);
-#endif
-}
-
-/* Bodge the above for when we don't have a specific thing to do other
+/* Bodge dohelp for when we don't have a specific thing to do other
    than display a message code.  */
 
 void	dochelp(WINDOW *wp, const int code)
@@ -549,86 +386,6 @@ void	endhe(WINDOW *owin, WINDOW **wpp)
 #endif
 }
 
-/* Generate error message avoiding (if possible) current cursor position.  */
-
-void	doerror(WINDOW *wp, const int Errnum)
-{
-	char	**ev;
-	int	erows, ecols, rows, cols;
-	int	begy, cy, startrow, startcol, i, l;
-
-#ifdef	HAVE_TERMINFO
-	flash();
-#else
-	putchar('\007');
-#endif
-
-	if  (*(ev = helpvec(Errnum, 'E')) == (char *) 0)  {
-		free((char *) ev);
-		disp_arg[0] = Errnum;
-		ev = helpvec($E{Missing error code}, 'E');
-	}
-
-	count_hv(ev, &erows, &ecols);
-	rows = erows;
-	cols = ecols;
-
-	if  (errbox)  {
-		rows += BOXWID * 2;
-		cols += BOXWID * 2;
-	}
-
-	/* Silly person might make error messages too big.  */
-
-	if  (cols > COLS)  {
-		ecols -= cols - COLS;
-		cols = COLS;
-	}
-
-	/* Find absolute cursor position and try to create window avoiding it.  */
-
-	getbegyx(wp, begy, i);
-	getyx(wp, cy, i);
-	cy += begy;
-	if  (cy >= LINES/2)
-		startrow = 0;
-	else
-		startrow = LINES - rows;
-	startcol = (COLS - cols) / 2;
-
-	if  ((escr = newwin(rows <= 0? 1: rows, cols, startrow, startcol)) == (WINDOW *) 0)
-		nomem();
-
-	if  (errbox)  {
-#ifdef	HAVE_TERMINFO
-		box(escr, 0, 0);
-#else
-		box(escr, '|', '-');
-#endif
-		for  (i = 0;  i < erows;  i++)
-			mvwaddstr(escr, i+BOXWID, BOXWID, ev[i]);
-	}
-	else  {
-		wstandout(escr);
-
-		for  (i = 0;  i < erows;  i++)  {
-			mvwaddstr(escr, i, 0, ev[i]);
-			for  (l = strlen(ev[i]);  l < ecols;  l++)
-				waddch(escr, ' ');
-		}
-	}
-	freehelp(ev);
-
-#ifdef HAVE_TERMINFO
-	wnoutrefresh(escr);
-	wnoutrefresh(wp);
-	doupdate();
-#else
-	wrefresh(escr);
-	wrefresh(wp);
-#endif
-}
-
 /* This accepts input from the screen.  */
 
 void	process(int inpq)
@@ -637,7 +394,7 @@ void	process(int inpq)
 
 #ifdef	STRUCT_SIG
 	struct	sigstruct_name	z;
-	z.sighandler_el = markit;
+	z.sighandler_el = sh_markit;
 	sigmask_clear(z);
 	z.sigflags_el = SIGVEC_INTFLAG | SIGACT_INTSELF;
 	sigact_routine(QRFRESH, &z, (struct sigstruct_name *) 0);
@@ -645,7 +402,7 @@ void	process(int inpq)
 	sigact_routine(SIGALRM, &z, (struct sigstruct_name *) 0);
 #else
 	/* signal is #defined as sigset on suitable systems */
-	signal(QRFRESH, markit);
+	signal(QRFRESH, sh_markit);
 	signal(SIGALRM, pollit);
 #endif
 	oreq.spr_un.o.spr_arg1 = Realuid;
@@ -983,7 +740,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
