@@ -35,24 +35,16 @@
 #include "incl_unix.h"
 #include "incl_ugid.h"
 #include "cfile.h"
-#ifdef	SHAREDLIBS
 #include "network.h"
 #include "spq.h"
 #include "xfershm.h"
 #include "q_shm.h"
-#include "displayopt.h"
-#endif
 
 unsigned Nusers;
 extern	struct	sphdr	Spuhdr;
 struct	spdet	*ulist;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
 char	*Curr_pwd;
-FILE	*Cfile;
 
 static	char	set_default,
 		copyall,
@@ -110,17 +102,6 @@ struct	perm	{
 
 #define	MAXPERM	(sizeof (ptab)/sizeof(struct perm))
 
-#ifdef	SHAREDLIBS
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
-struct	xfershm		*Xfer_shmp;
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-DEF_DISPOPTS;
-#endif
-
 int	proc_save_opts(const char *, const char *, void (*)(FILE *, const char *));
 int	spitoption(const int, const int, FILE *, const int, const int);
 
@@ -603,7 +584,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.2 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
