@@ -46,13 +46,10 @@
 #include "incl_unix.h"
 #include "incl_ugid.h"
 #include "cfile.h"
-#ifdef	SHAREDLIBS
 #include "network.h"
 #include "spq.h"
 #include "xfershm.h"
 #include "q_shm.h"
-#include "displayopt.h"
-#endif
 
 #ifdef	OS_BSDI
 #define	_begy	begy
@@ -72,8 +69,6 @@
 int	LINES;			/* Not defined anywhere without extern */
 #endif
 
-#define	BOXWID	1
-
 unsigned Nusers;
 extern	struct	sphdr	Spuhdr;
 struct	spdet	*ulist;
@@ -81,19 +76,15 @@ struct	spdet	*ulist;
 #define	SORT_NONE	0
 #define	SORT_USER	1
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
 char	iflag,
 	cflag,
-	alphsort = SORT_NONE,
-	helpclr,
-	helpbox,
-	errbox;
+	alphsort = SORT_NONE;
+
+extern	char	helpclr, helpbox, errbox;	/* Def moved to library wgets */
+extern	void	dohelp(WINDOW *, struct sctrl *, const char *);
+extern	void	doerror(WINDOW *, const int);
 
 char	*Curr_pwd;
-FILE	*Cfile;
 
 int	Current_user,
 	Top_user,
@@ -105,10 +96,7 @@ int	Current_user,
 
 WINDOW	*hscr,
 	*dscr,
-	*tpscr,
-	*hlpscr,
-	*escr,
-	*Ew;
+	*tpscr;
 
 int	DLINES,
 	HLINES,
@@ -209,17 +197,6 @@ struct	termios	orig_term;
 struct	termio	orig_term;
 #endif
 
-#ifdef	SHAREDLIBS
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
-struct	xfershm		*Xfer_shmp;
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-DEF_DISPOPTS;
-#endif
-
 void	exit_cleanup(void)
 {
 	if  (Win_setup)  {
@@ -245,7 +222,7 @@ void	nomem(void)
 
 /* Provide lists of forms */
 
-char **	uhelpform(const char *sofar, const int hf)
+char **uhelpform(const char *sofar, const int hf)
 {
 	unsigned  ucnt, sfl = 0;
 	char	**result, **rp;
@@ -358,105 +335,7 @@ RETSIGTYPE	catchit(int n)
 	exit(E_SIGNAL);
 }
 
-/* Generate help message.  */
-
-void	dohelp(WINDOW *owin, struct sctrl *scp, const char *prefix)
-{
-	char	**hv, **examples = (char **) 0;
-	int	hrows, hcols, erows, ecols, cols, rows;
-	int	begy, cy, cx, startrow, startcol, i, l;
-
-	if  (*(hv = helpvec(scp->helpcode, 'H')) == (char *) 0)  {
-		free((char *) hv);
-		disp_arg[0] = scp->helpcode;
-		hv = helpvec($E{Missing help code}, 'E');
-	}
-
-	if  (scp->helpfn)
-		examples = (*scp->helpfn)(prefix, 0);
-
-	count_hv(hv, &hrows, &hcols);
-	count_hv(examples, &erows, &ecols);
-	cols = hcols;
-
-	if  (ecols > cols)
-		cols = ecols;
-
-	rows = hrows + erows;
-	if  (helpbox)  {
-		rows += 2 * BOXWID;
-		cols += 2 * BOXWID;
-	}
-	if  (rows > LINES)
-		rows = LINES;
-	if  (cols > COLS)
-		cols = LINES;
-
-	/* Find absolute cursor position and try to create window avoiding it.  */
-
-	getyx(owin, cy, cx);
-	getbegyx(owin, begy, i);
-	cy += begy;
-	if  ((startrow = cy - rows/2) < 0)
-		startrow = 0;
-	else  if  (startrow + rows > LINES)
-		startrow = LINES - rows;
-	if  ((startcol = cx - cols/2) < 0)
-		startcol = 0;
-	else  if  (startcol + cols > COLS)
-		startcol = COLS - cols;
-
-	if  (cx + cols + 2 < COLS)
-		startcol = COLS - cols - 1;
-	else  if  (cx - cols - 1 >= 0)
-		startcol = cx - cols - 1;
-	else  if  (cy + rows + 2 < LINES)
-		startrow = cy + 2;
-	else  if  (cy - rows - 1 >= 0)
-		startrow = cy - rows - 1;
-
-	if  ((hlpscr = newwin(rows <= 0? 1: rows, cols, startrow, startcol)) == (WINDOW *) 0)
-		nomem();
-
-	if  (helpbox)  {
-#ifdef	HAVE_TERMINFO
-		box(hlpscr, 0, 0);
-#else
-		box(hlpscr, '|', '-');
-#endif
-		for  (i = 0;  i < hrows;  i++)
-			mvwaddstr(hlpscr, i + BOXWID, BOXWID, hv[i]);
-		for  (i = 0;  i < erows;  i++)
-			mvwaddstr(hlpscr, i + hrows + BOXWID, BOXWID, examples[i]);
-	}
-	else  {
-		wstandout(hlpscr);
-
-		for  (i = 0;  i < hrows;  i++)  {
-			mvwaddstr(hlpscr, i, 0, hv[i]);
-			for  (l = strlen(hv[i]);  l < cols;  l++)
-				waddch(hlpscr, ' ');
-		}
-		for  (i = 0;  i < erows;  i++)  {
-			mvwaddstr(hlpscr, i+hrows, 0, examples[i]);
-			for  (l = strlen(hv[i]);  l < cols;  l++)
-				waddch(hlpscr, ' ');
-		}
-	}
-	freehelp(hv);
-	freehelp(examples);
-
-#ifdef HAVE_TERMINFO
-	wnoutrefresh(hlpscr);
-	wnoutrefresh(owin);
-	doupdate();
-#else
-	wrefresh(hlpscr);
-	wrefresh(owin);
-#endif
-}
-
-/* Bodge the above for when we don't have a specific thing to do other
+/* Bodge dohelp for when we don't have a specific thing to do other
    than display a message code.  */
 
 static	void	dochelp(WINDOW *wp, int code)
@@ -500,83 +379,6 @@ void	endhe(WINDOW *owin, WINDOW **wpp)
 #endif
 }
 
-/* Generate error message avoiding (if possible) current cursor position.  */
-
-void	doerror(WINDOW *wp, const int Errnum)
-{
-	char	**ev;
-	int	erows, ecols, rows, cols;
-	int	begy, cy, startrow, startcol, i, l;
-
-#ifdef	HAVE_TERMINFO
-	flash();
-#else
-	putchar('\007');
-#endif
-
-	if  (*(ev = helpvec(Errnum, 'E')) == (char *) 0)  {
-		free((char *) ev);
-		disp_arg[0] = Errnum;
-		ev = helpvec($E{Missing error code}, 'E');
-	}
-
-	count_hv(ev, &erows, &ecols);
-	rows = erows;
-	cols = ecols;
-	if  (errbox)  {
-		rows += 2 * BOXWID;
-		cols += 2 * BOXWID;
-	}
-	if  (cols > COLS)  {
-		ecols -= cols - COLS;
-		cols = COLS;
-	}
-
-	/* Find absolute cursor position and try to create window
-	   avoiding it.  */
-
-	getyx(wp, cy, i);
-	getbegyx(wp, begy, i);
-	cy += begy;
-	if  (cy >= LINES/2)
-		startrow = 0;
-	else
-		startrow = LINES - rows;
-	startcol = (COLS - cols) / 2;
-
-	if  ((escr = newwin(rows <= 0? 1: rows, cols, startrow, startcol)) == (WINDOW *) 0)
-		nomem();
-
-	if  (errbox)  {
-#ifdef	HAVE_TERMINFO
-		box(escr, 0, 0);
-#else
-		box(escr, '|', '-');
-#endif
-		for  (i = 0;  i < erows;  i++)
-			mvwaddstr(escr, i + BOXWID, BOXWID, ev[i]);
-	}
-	else  {
-		wstandout(escr);
-
-		for  (i = 0;  i < erows;  i++)  {
-			mvwaddstr(escr, i, 0, ev[i]);
-			for  (l = strlen(ev[i]);  l < ecols;  l++)
-				waddch(escr, ' ');
-		}
-	}
-	freehelp(ev);
-
-#ifdef HAVE_TERMINFO
-	wnoutrefresh(escr);
-	wnoutrefresh(wp);
-	doupdate();
-#else
-	wrefresh(escr);
-	wrefresh(wp);
-#endif
-}
-
 int	cpriv(char *uname, ULONG *fp)
 {
 	ULONG	 result = *fp;
@@ -754,9 +556,12 @@ mc:			move(currow, pcol[currow-srow]);
 				}  while  (ch != $K{spuser key yes} && ch != $K{spuser key no});
 
 				if  (ch == $K{spuser key yes})
-					for  (i = 0;  i < Nusers;  i++)
-						if  (ulist[i].spu_user != Realuid)
+					for  (i = 0;  i < Nusers;  i++)  {
+						int_ugid_t uu = ulist[i].spu_user;
+						/* We don't really need this check technically but it gets the display right */
+						if  (uu != Realuid && uu != Daemuid && uu != ROOTID)
 							ulist[i].spu_flgs = result;
+					}
 				free(pp);
 			}
 #ifdef	CURSES_MEGA_BUG
@@ -2064,7 +1869,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.2 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
